@@ -438,8 +438,16 @@ def popup_json(found, popup_id=None, hide_add_snippet=False, request=None):
         # Add workspace_item name on top
         # title = workspace_item.name
 
-        identifiers = [display_object['identifier'] for display_object
-                       in display_group]
+        try:
+            identifiers = [display_object['identifier']
+                           for display_object in display_group]
+        except:
+            logger.critical(
+                "No 'identifier' found in a display_object. Perhaps an "
+                "incorrect shapefile?")
+            identifiers = None
+        if identifiers is None:
+            continue
         # img_url = workspace_item_image_url(workspace_item.id, identifiers)
 
         html_per_workspace_item = workspace_item.adapter.html(
@@ -689,7 +697,7 @@ def snippet_edit(request, snippet_id=None, visible=None):
         snippet_id = post['snippet_id']
     snippet = get_object_or_404(WorkspaceCollageSnippet, pk=snippet_id)
     if visible is None:
-        if post['visible']:
+        if 'visible' in post:
             visible = post['visible']
     if visible:
         lookup = {'true': True, 'false': False}
